DataConnector
========================================================

.. toctree::
    :maxdepth: 1

    Base Class for DataConnector <base>

Built-in DataConnector
-----------------------------

.. toctree::
    :maxdepth: 2

    CsvConnector <csv_connector>
    GeneratorConnector <generator_connector>

Custom DataConnector Relevant
-----------------------------

.. toctree::
    :maxdepth: 2

    Extension hookspec <extension>
    DataConnectorManager <manager>
